js.bootstrap_wysihtml5
**********************

Introduction
============

This library packages `bootstrap_wysihtml5`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`bootstrap_wysihtml5`: http://jhollingworth.github.com/bootstrap-wysihtml5/

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js.bootstrap_wysihtml5``) are published to some URL.
